pub struct MovingAiMap { /* private fields */ }Expand description
Contains data structure for 2D MovingAI maps. An immutable representation of a MovingAI map.
Implementations
Sourceimpl MovingAiMap
impl MovingAiMap
Sourcepub fn new(
map_type: String,
height: usize,
width: usize,
map: Vec<char>,
) -> Result<MovingAiMap, ParseError>
pub fn new( map_type: String, height: usize, width: usize, map: Vec<char>, ) -> Result<MovingAiMap, ParseError>
Create a new MovingAIMap object from basic components.
Arguments
map_type: The type of map you are registering. Usuallyoctile.height: the height of the map.width: the width of the map.map: A vector representing the map in row-major order.
Errors
Returns an error if the size of the map vector is different from height * width.
Sourcepub fn new_from_slice(
map_type: String,
height: usize,
width: usize,
map: Box<[char]>,
) -> Result<MovingAiMap, ParseError>
pub fn new_from_slice( map_type: String, height: usize, width: usize, map: Box<[char]>, ) -> Result<MovingAiMap, ParseError>
Create a new MovingAIMap object from basic components.
Arguments
map_type: The type of map you are registering. Usuallyoctile.height: the height of the map.width: the width of the map.map: A boxed slice representing the map in row-major order.
Errors
Returns an error if the size of the map vector is different from height * width.